<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ko">
<context>
    <name>LXQtMainMenu</name>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="113"/>
        <source>Search...</source>
        <translation>검색...</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="123"/>
        <source>Show/hide main menu</source>
        <translation>메뉴 표시/숨김</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="522"/>
        <source>Add to desktop</source>
        <translation>바탕화면에 추가</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="530"/>
        <source>Question</source>
        <translation>질문</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="531"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>같은 이름의 파일이 이미 있습니다.
덮어쓰시겠습니까?</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="537"/>
        <source>Warning</source>
        <translation>경고</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="538"/>
        <source>The file cannot be overwritten.</source>
        <translation>파일을 덮어쓸 수 없습니다.</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenu.cpp" line="544"/>
        <source>Copy</source>
        <translation>복사</translation>
    </message>
</context>
<context>
    <name>LXQtMainMenuConfiguration</name>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>일반</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="14"/>
        <source>Main Menu settings</source>
        <translation>기본 메뉴 설정</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>아이콘:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>버튼 텍스트:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>사용자 지정 글꼴 크기:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>메뉴 파일</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>메뉴 파일:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>검색</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="162"/>
        <source>Max. item width:</source>
        <translation>최대 항목 너비:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="169"/>
        <source>Show matching entries:</source>
        <translation>일치하는 항목 표시:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="183"/>
        <source>Maximum visible items:</source>
        <translation>최대 표시 항목:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="190"/>
        <source>Filter menu entries</source>
        <translation>필터 메뉴 항목</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="197"/>
        <source> px</source>
        <translation> 픽셀</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="210"/>
        <source>Hide menu entries while searching</source>
        <translation>검색하는 동안 메뉴 항목 숨김</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="217"/>
        <source>Clear search upon showing menu</source>
        <translation>메뉴 표시 시 검색 지우기</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>키보드 단축키</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>단축키를 기록하려면 버튼 클릭:</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="76"/>
        <source>Reset</source>
        <translation>재설정</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="176"/>
        <source>Choose icon file</source>
        <translation>아이콘 파일 선택하기</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="178"/>
        <source>Images (*.svg *.png)</source>
        <translation>이미지 (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="190"/>
        <source>Choose menu file</source>
        <translation>메뉴 파일 선택하기</translation>
    </message>
    <message>
        <location filename="../lxqtmainmenuconfiguration.cpp" line="192"/>
        <source>Menu files (*.menu)</source>
        <translation>메뉴 파일 (*.menu)</translation>
    </message>
</context>
</TS>
